﻿'A reference to the Phidget22.NET.dll must be added to new projects in VB.Net 
'From the "Project" menu select "Add Reference" 
'From the "Add Reference" window select the "Browse" tab 
'Browse to the directory you installed the Phidgets library to 
'The default is "C:\Program Files\Phidgets" 
'Select "Phidget22.NET.dll" and click "OK" 
'To view objects that have been added, select the "View" menu 
'Select "Object Browser" 
'Then expand the Phidget22.NET.dll item 



Imports Phidget22
Imports Phidget22.Events

Public Class Form1
    Dim WithEvents device As Phidget22.LCD
    Dim open As ExampleUtils.ExampleUtils.CommandLineOpen
    Dim errorBox As ErrorEventBox

    Public Sub New()
        open = New ExampleUtils.ExampleUtils.CommandLineOpen(Me)
        ' This call is required by the Windows Form Designer.
        Phidget22.Phidget.InvokeEventCallbacks = True
        InitializeComponent()
        ' Add any initialization after the InitializeComponent() call.
    End Sub

    Public Sub New(ByVal commandLine As String())
        open = New ExampleUtils.ExampleUtils.CommandLineOpen(Me)
        open.commandLine = commandLine
        Phidget22.Phidget.InvokeEventCallbacks = True
        InitializeComponent()
    End Sub

    Private Sub Form1_Load(sender As Object, e As EventArgs) Handles MyBase.Load
        screenSizeCombo.DataSource = [Enum].GetValues(GetType(Phidget22.LCDScreenSize))
        screenSizeCombo.SelectedIndex = -1

        errorBox = New ErrorEventBox(Me)
        device = New Phidget22.LCD()

        Dim phidgetParameters As ExampleUtils.commandLineData = open.parseCmdLine()

        Try 'set all the values grabbed from command line.  these values have defaults that are set in ExampleUtils.vb, you can check there to see them
            device.Channel = phidgetParameters.Channel 'selects the channel on the device to open
            device.DeviceSerialNumber = phidgetParameters.SerialNumber 'selects the device or hub to open
            device.HubPort = phidgetParameters.HubPort 'selects th eport on the hub to open
            device.IsHubPortDevice = phidgetParameters.isHubPortDevice 'is the device a port on a vint hub?

            If phidgetParameters.isRemote Then 'are we trying to open a remote device?
                device.IsRemote = True
                Net.EnableServerDiscovery(ServerType.Device) 'turn on network scan
                If phidgetParameters.Password <> vbNullString And phidgetParameters.ServerName <> vbNullString Then
                    Net.SetServerPassword(phidgetParameters.ServerName, phidgetParameters.Password)
                End If
            Else
                device.IsLocal = True
            End If

            device.Open() 'open the device specified by the above parameters
        Catch ex As PhidgetException
            errorBox.addMessage("Error opening the device: " + ex.Message)
        End Try
    End Sub

    Private Sub Form1_FormClosing(sender As Object, e As FormClosingEventArgs) Handles MyBase.FormClosing
        Application.DoEvents()
        If device.Attached Then
            device.Close()
        End If
    End Sub

    'attach event handler...we will display the attach status And the attached TextLCD device's details
    'We will also enable the fields used to manipulate the TextLCD as well as do some initializing of
    'ranges And maximum values for some of these fields
    Private Sub device_Attach(ByVal sender As Object, ByVal e As Phidget22.Events.AttachEventArgs) Handles device.Attach

        Dim attachedDevice As Phidget22.LCD = CType(sender, Phidget22.LCD)
        PhidgetInfoBox1.FillPhidgetInfo(CType(sender, Phidget))

        dispText1.MaxLength = device.Width
        dispText2.MaxLength = device.Width
        customChrChk.Checked = False

        Try
            contrastTrkBr.Value = CType(attachedDevice.Contrast * contrastTrkBr.Maximum, Integer)
        Catch ex As Exception
            contrastTrkBr.Value = 130
        End Try

        Try
            attachedDevice.Backlight = 0.75
            brightnessTrkBr.Value = CType(attachedDevice.Backlight * brightnessTrkBr.Maximum, Integer)
        Catch ex As Exception
            brightnessTrkBr.Value = 0
        End Try

        Try
            Select Case attachedDevice.DeviceID
                Case DeviceID.PN_1202_1203
                    screenSizeCombo.Visible = False
                    screenSizeLbl.Visible = False
                Case Else
                    screenSizeCombo.Visible = True
                    screenSizeLbl.Visible = True
                    screenSizeCombo.SelectedIndex = 2
                    attachedDevice.ScreenSize = CType([Enum].Parse(GetType(LCDScreenSize), screenSizeCombo.SelectedValue.ToString()), LCDScreenSize)
            End Select
        Catch ex As PhidgetException
            errorBox.addMessage("Error setting screen size: " + ex.Message())
        End Try

        settingsBox.Visible = True
    End Sub

    'detach event handler.... we will display the device attach status and clear all the other fields
    Private Sub device_Detach(ByVal sender As Object, ByVal e As Phidget22.Events.DetachEventArgs) Handles device.Detach
        PhidgetInfoBox1.Clear()
        settingsBox.Visible = False
    End Sub

    'Error event handler..we will simply display the error details text in a popup message box
    Private Sub device_Error(ByVal sender As Object, ByVal e As Phidget22.Events.ErrorEventArgs) Handles device.Error
        errorBox.addMessage(e.Description)
    End Sub

    'line 1 textChanged event handler...when the user is entering text, pass it on to the textLCD to be displayed
    Private Sub dispText1_TextChanged(sender As Object, e As EventArgs) Handles dispText1.TextChanged
        Try
            Dim tb As TextBox = CType(sender, TextBox)
            device.WriteText(LCDFont.Dimensions_5x8, 0, 0, "".PadLeft(device.Width))
            device.WriteText(LCDFont.Dimensions_5x8, 0, 0, tb.Text)
            device.Flush()
        Catch ex As PhidgetException
            errorBox.addMessage("Error setting line 1: " + ex.Message)
        End Try
    End Sub

    'line 2 textChanged event handler...when the user is entering text, pass it on to the textLCD to be displayed
    Private Sub dispText2_TextChanged(sender As Object, e As EventArgs) Handles dispText2.TextChanged
        Try
            Dim tb As TextBox = CType(sender, TextBox)
            device.WriteText(LCDFont.Dimensions_5x8, 0, 1, "".PadLeft(device.Width))
            device.WriteText(LCDFont.Dimensions_5x8, 0, 1, tb.Text)
            device.Flush()
        Catch ex As PhidgetException
            errorBox.addMessage("Error setting line 2: " + ex.Message)
        End Try
    End Sub

    'If the clear button is clicked, we want to clear the fields as well as clear the TextLCD screen
    Private Sub clearBtn_Click(sender As Object, e As EventArgs) Handles clearBtn.Click
        Try
            dispText2.Clear()
            dispText1.Clear()
            device.Clear()
        Catch ex As Exception
            errorBox.addMessage("Error clearing screen: " + ex.Message)
        End Try
    End Sub

    'display ou simulation of the custom characters when the checkbox is clicked
    Private Sub customChrChk_CheckedChanged(sender As Object, e As EventArgs) Handles customChrChk.CheckedChanged
        dispText1.Text = ""
        dispText2.Text = ""

        Try
            Dim chk As CheckBox = CType(sender, CheckBox)
            If (chk.Checked) Then
                Dim smileyface As Byte() = getBitmapBytes(
                    "          " +
                    "  ██  ██  " +
                    "          " +
                    "    ██    " +
                    "          " +
                    "██      ██" +
                    "  ██████  " +
                    "          ")
                Dim sadface As Byte() = getBitmapBytes(
                    "          " +
                    "  ██  ██  " +
                    "          " +
                    "    ██    " +
                    "          " +
                    "  ██████  " +
                    "██      ██" +
                    "          ")
                Dim musicNotes As Byte() = getBitmapBytes(
                    "        ██" +
                    "      ████" +
                    "    ██  ██" +
                    "  ██    ██" +
                    "  ██    ██" +
                    "  ██  ████" +
                    "████  ████" +
                    "████      ")
                Dim bell As Byte() = getBitmapBytes(
                    "    ██    " +
                    "  ██████  " +
                    "  ██████  " +
                    "  ██████  " +
                    "██████████" +
                    "          " +
                    "    ██    " +
                    "          ")
                Dim heart As Byte() = getBitmapBytes(
                    "          " +
                    "  ██  ██  " +
                    "██████████" +
                    "██████████" +
                    "  ██████  " +
                    "    ██    " +
                    "          " +
                    "          ")

                device.SetCharacterBitmap(LCDFont.Dimensions_5x8, Chr(CInt("&H8")), smileyface)
                device.SetCharacterBitmap(LCDFont.Dimensions_5x8, Chr(CInt("&H9")), sadface)
                device.SetCharacterBitmap(LCDFont.Dimensions_5x8, Chr(CInt("&HA")), musicNotes)
                device.SetCharacterBitmap(LCDFont.Dimensions_5x8, Chr(CInt("&HB")), bell)
                device.SetCharacterBitmap(LCDFont.Dimensions_5x8, Chr(CInt("&HC")), heart)

                device.Clear()
                device.WriteText(LCDFont.Dimensions_5x8, 0, 0, "Custom " + Chr(CInt("&H8")) + Chr(CInt("&H9")) + Chr(CInt("&H9")) + Chr(CInt("&H9")) + Chr(CInt("&HA")) + Chr(CInt("&HB")) + Chr(CInt("&HC")))
                device.WriteText(LCDFont.Dimensions_5x8, 0, 1, "Characters! " + Chr(CInt("&H8")) + Chr(CInt("&H9")) + Chr(CInt("&H8")) + Chr(CInt("&H9")))
                device.Flush()
            Else
                device.Clear()
                device.Flush()
            End If
        Catch ex As Exception
            errorBox.addMessage("Error setting custom characters: " + ex.Message)
            customChrChk.Checked = False
        End Try
    End Sub

    'adjust the contast of the screen on the textLCD based on the value selected on the slider (100 to 0)
    Private Sub contrastTrkBr_Scroll(sender As Object, e As EventArgs) Handles contrastTrkBr.Scroll
        Try
            device.Contrast = contrastTrkBr.Value / CType(contrastTrkBr.Minimum, Double)
        Catch ex As Exception
            errorBox.addMessage("Error setting contrast: " + ex.Message)
        End Try
    End Sub

    Private Sub brightnessTrkBr_Scroll(sender As Object, e As EventArgs) Handles brightnessTrkBr.Scroll
        Try
            device.Backlight = brightnessTrkBr.Value / CType(brightnessTrkBr.Maximum, Double)
        Catch ex As Exception
            errorBox.addMessage("Error setting backlight: " + ex.Message)
        End Try
    End Sub

    Private Sub cursorChk_CheckedChanged(sender As Object, e As EventArgs) Handles cursorChk.CheckedChanged
        Try
            device.CursorOn = cursorChk.Checked
        Catch ex As Exception
            errorBox.addMessage("Error setting cursor: " + ex.Message)
        End Try
    End Sub

    Private Sub cursorBlinkChk_CheckedChanged(sender As Object, e As EventArgs) Handles cursorBlinkChk.CheckedChanged
        Try
            device.CursorBlink = cursorBlinkChk.Checked
        Catch ex As Exception
            errorBox.addMessage("Error setting cursor blink: " + ex.Message)
        End Try
    End Sub

    Private Function getBitmapBytes(ByVal charStr As String) As Byte()
        Dim bytes(charStr.Length / 2) As Byte
        For i As Integer = 0 To (charStr.Length / 2) - 1
            bytes(i) = If(charStr.ToArray()(i * 2) = " ", &H00, &H01)
        Next
        Return bytes
    End Function

    Private Sub screenSizeCombo_SelectedIndexChanged(sender As Object, e As EventArgs) Handles screenSizeCombo.SelectedIndexChanged
        If (CType(sender, ComboBox).SelectedIndex = -1 Or device Is Nothing) Then
            Return
        End If

        Try
            device.ScreenSize = CType([Enum].Parse(GetType(LCDScreenSize), screenSizeCombo.SelectedValue.ToString()), LCDScreenSize)
        Catch ex As Exception
            errorBox.addMessage("Error setting screen size: " + ex.Message)
        End Try
    End Sub

    Private Sub initBtn_Click(sender As Object, e As EventArgs) Handles initBtn.Click
        Try
            If (device.DeviceID <> DeviceID.PN_1202_1203) Then
                device.Initialize()
            End If
        Catch ex As Exception
            errorBox.addMessage("Error initializing screen: " + ex.Message)
        End Try
    End Sub
End Class
